from flask import Flask, request
import copy
from crossref_commons.iteration import iterate_publications_as_json
from ratelimit import limits, sleep_and_retry



# Threshold for CrossRef reference lookup score – if score of found DOI is lower than this, DOI is not returned as the results is considered unreliable
score_threshold = 85


@sleep_and_retry
@limits(calls=50,
        period=1)  # Allows 50 requets within 1 second; sleep till the request period has ellapsed and then retry
def find_doi_using_api(queries):
    for p in iterate_publications_as_json(max_results=1, queries=copy.deepcopy(queries)):
        return p["DOI"], p["score"]


def decide_correctness_of_doi(attribute_meta_data, text_meta_data):
    if attribute_meta_data is not None and text_meta_data is not None:
        doi_using_attributes, doi_using_attributes_score = attribute_meta_data
        doi_using_text, doi_using_text_score = text_meta_data
        if float(doi_using_attributes_score) > float(doi_using_text_score) > score_threshold:
            return doi_using_attributes , doi_using_attributes_score
        elif float(doi_using_text_score) > float(doi_using_attributes_score) > score_threshold:
            return doi_using_text, doi_using_text_score

    if attribute_meta_data is not None and text_meta_data is None:
        doi_using_attributes, doi_using_attributes_score = attribute_meta_data
        if float(doi_using_attributes_score) > score_threshold:
            return doi_using_attributes, doi_using_attributes_score

    if text_meta_data is not None and attribute_meta_data is None:
        doi_using_text, doi_using_text_score = text_meta_data
        if float(doi_using_text_score) > score_threshold:
            return doi_using_text, doi_using_text_score

    return "", ""


def create_query_using_text(query):
    query_using_text = {
        "query.bibliographic": ', '.join([query["query.author"], query["query.title"], query["query.bibliographic"]])}
    return query_using_text