import requests
from bs4 import BeautifulSoup
from ratelimit import limits, sleep_and_retry

import shared

@sleep_and_retry
@limits(calls=50,
        period=1)  # Allows 50 requets within 1 second; sleep till the request period has ellapsed and then retry
def find_mr_and_metadata(author, title, suffix):

    first_page, last_page = shared.get_page_range_from_suffix(suffix)
    year = shared.get_publication_year_from_suffix(suffix)
    payload = {
        "au": f"{author}",
        "ti": f"{title}",
        "jrnl": "",
        "ipage": f"{first_page}",
        "fpage": f"{last_page}",
        "year": f"{year}",
        "format": "mrcit",
        "Search": "Search",
    }

    html_text = requests.post(
        "https://mathscinet.ams.org/mrlookup", data=payload).text

    soup = BeautifulSoup(html_text, features="lxml")
    book = soup.find_all("tr")[13]

    if book is not None and book.find("a") is not None:
        mr = book.find("a").text
        if mr!= "":
            mr_link = f"https://mathscinet.ams.org/mathscinet-getitem?mr={mr[2:]}"
            return mr, mr_link
    return "", ""
